<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>config.py 中有错误：</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>运行插件时出错：</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>无法载入文件。</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>无效的文件格式。</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>无法保存文件。</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>无法解析XML：</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>无法识别的编码。</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>在行上缺少答案：</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>无法载入数据库。创建临时文件。</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>文件已存在：</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>覆盖(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>删除的重复项： </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>有卡片对问题有不同答案：

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>合并后编辑(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>不要合并(&amp;D)</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>完成！</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation>你还不记得这张卡片。</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation>类似于‘0’，但它正变得更熟悉。</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation>更少地显示它。</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation>现在你记下了这张卡片，</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation>并可能记住几天。</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation>你完全忘记了这张卡片。</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation>勉强正确的答案。间隔的时间实在太长了。</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation>正确的答案，但非常费劲。</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation>间隔的时间可能太长了。</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation>正确的答案，需要稍作努力。</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation>间隔的时间可能正好。</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation>正确的答案，但没有任何</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation>困难。间隔的时间可能太短了。</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>主要作者： Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.sourceforge.net
</source>
        <translation type="obsolete">更多信息： http://mnemosyne-proj.sourceforge.net
</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>激活分类</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>选择要激活的分类：</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>无一激活</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>全部激活</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;默认&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>放弃当前卡片？</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>是(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>否(&amp;N)</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>问题：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>文字形式：</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>翻译：</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>卡片已在数据库中。
</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>重复项没有被添加。</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>有不同答案回答了</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation>这个问题：

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>合并后编辑(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>照此添加(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>不要添加(&amp;D)</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>添加卡片</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>分类：</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>问题：</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>发音：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>也添加相反卡片(&amp;V)</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>选择初始评分：</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>你还不记得这张卡片或者忘记了。</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>类似于‘0’，但它正变得更熟悉。</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>现在你记下了这张卡片，并可能记住几天。</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>正确的答案，但非常费劲。间隔的时间可能太长了。</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>正确的答案，需要稍作努力。间隔的时间可能正好。</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>正确的答案，但没有任何困难。间隔的时间可能太短了。</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>输入问题和答案，然后选取初始评分。</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">预览(&amp;P)</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>退出(&amp;X)</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>更改分类</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>分类：</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Mnemosyne 配置</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>把鼠标指针悬停在按钮上来获得额外信息。</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>设置问题／答案字体</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>设置用于显示单个问题和答案的字体</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>设置列表字体</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>设置用于显示卡片叠中所有卡片列表的字体</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>增加非拉丁字符大小</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>复杂的符号用默认的拉丁字体大小往往很难读</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>磅(pt)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>日志上传</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>上传匿名日志</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>分享匿名统计信息来为记忆研究做贡献</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>重复项处理</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>添加新卡片时检查重复项</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>允许不同分类中有重复项</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>重复过程</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">一次学习0分卡片数量：</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>注意：这并不是你 *每天* 想要记下的0分卡片数量</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>默认设置</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>编辑卡片</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>分类：</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>问题：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>预览(&amp;P)</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>请稍候...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>预览(&amp;P)</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>添加相反卡片(&amp;A)</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>统计(&amp;T)</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>更改分类(&amp;C)</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>添加相反卡片(&amp;V)</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>为这些卡片添加相反卡片？</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>为这张卡片添加相反卡片？</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

如果已经存在相反卡片，</translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>就会产生重复卡片，因此之后你可能要运行</translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>清除重复卡片。</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>是(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>否(&amp;N)</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>评分：</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>容易程度：</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>重复次数：</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>错过次数：</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>自从上次重复的天数：</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>直到下次重复的天数：</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>删除这些卡片？</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>删除这张卡片？</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>你所输入的文本没有找到。</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>再找(&amp;F)</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>查找(&amp;F)</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="obsolete"></translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>答案</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>分类</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>编辑卡片叠</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>查找(&amp;F)</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>要编辑一张卡片，请右击它。</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>退出(&amp;X)</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>所有文件 (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>导出到文件</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>文件格式：</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>导出到文件：</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>浏览(&amp;B)</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>要导出的分类：</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>选择全部(&amp;S)</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>导出时重置学习数据</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;默认&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>所有文件 (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>导入</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>从文件导入</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>文件格式：</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>从文件导入：</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>浏览(&amp;B)</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>将没有分类的卡片放到这个分类中：</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>注意：所有卡片将被添加到当前数据库。</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>导入时重置学习数据</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation>Mnemosyne 数据库 (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>请稍候...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation>删除当前卡片？</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>是(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>否(&amp;N)</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation>在</translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation>天后返回。</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation>下次重复：今天。</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation>下次重复：明天。</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation>下次重复在</translation>
    </message>
    <message>
        <source> days.</source>
        <translation>天后。</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>问题：</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;默认&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">显示答案(&amp;A)</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation>提前学习</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation>选取直到下次重复的天数：</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>给你的答案评分：</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation>计划：</translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation>未记：</translation>
    </message>
    <message>
        <source>All: </source>
        <translation>所有：</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">显示答案</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>问题：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>显示答案</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>给你的答案评分：</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建(&amp;N)</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>打开(&amp;O)...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>另存为(&amp;A)...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>退出(&amp;X)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>关于(&amp;A)</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>添加卡片</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>添加卡片(&amp;A)</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>激活分类(&amp;G)</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>编辑卡片叠</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>编辑卡片叠(&amp;D)</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>导入(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>导出(&amp;E)</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>显示工具栏(&amp;T)</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>编辑当前卡片</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>编辑当前卡片(&amp;E)</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>删除当前卡片</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>删除当前卡片(&amp;D)</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>清除重复项(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>配置 Mnemosyne(&amp;C)</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>入门指引</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>入门指引(&amp;G)</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Down, Down</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>显示统计</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>显示统计(&amp;T)</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>今日提示</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>今日提示(&amp;T)</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>主工具栏 (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>卡片叠(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>设置(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;默认&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>问题：</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>预览卡片</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>问题：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>入门指引</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>你好！

我是 Mnemosyne，以希腊的记忆女神命名的一种蝴蝶。

我能使你更有效地记住问题的答案，这是通过帮你集中精力于那些你最可能忘记的卡片，而不在你熟知的东西上浪费时间。

为此，我会决定什么时候问你问题，而你则需要为你对答案的记忆好坏打分。

现在让我们来看看这些评分的含义。</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>介绍</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>评分范围从0到5。

如果你还不知道答案，或者你已经忘记了，你就打0分或1分。比起0分来，1分的卡片正开始变得更熟悉，并将较少被重复。

我会不断问你这些问题，直到你给它们打2分或更高（具体的评分无关紧要）。2分基本表示你认为你能把这张卡片记住至少一两天。它是短期和长期记忆之间转换的信号。

我会把这张卡片安排在未来的某天，当我认为你仍能稍作努力而记起它，而不是完全忘了它。这对学习过程最为有效。</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>0-2分</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>如果将来我过早地问你问题，而你能毫不费力地记起它，你就给这张卡片打5分。顾及于此，我会等上很长时间再问你这个问题。

如果我做得恰到好处，使你虽需稍作努力，但能记起它，你就打4分。

然而如果你需要费很大劲才能记起答案，你觉得我等了太长时间才问你这个问题，那就打3分。

如果你完全无法记起，就打0或1分，我会不断问你这个问题，直到你认为你能再次把它记住几天。</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>3-5分</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>要是你对统计感兴趣，我可以为你的复习留下详细的日志。

不仅如此，如果你希望，我可以把这些日志的一个完全匿名的版本不知不觉地上传到一个中心站点用作分析，那你就能帮我变得更好了。以这种方式，你也为长期记忆的科学研究做出了贡献。

如果你不想做这件事，请取消下面的选框。</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>上传匿名日志</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>（以后你始终能更改这项设置，请用“配置 Mnemosyne”菜单项）</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>统计</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>现在你已经做好了开始的准备！
&lt;p&gt;
点击左上角带有加号的图标来添加新卡片。
&lt;p&gt;
记住，无需保存你的工作，我会自动保存的。
&lt;p&gt;
要获得最佳结果，我建议你每天做复习，尽管如果你想推迟复习或者提前学习的话，我会尽力应对的。
&lt;p&gt;
要看更多文档，请见 http://www.mnemosyne-proj.sourceforge.net。
&lt;p&gt;
祝你学习愉快！</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>准备开始</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>插入图片(&amp;I)</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>插入声音(&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>三面输入(&amp;3)</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>图片文件</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>插入图片</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>声音文件</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>插入声音</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation>今后几天计划的卡片数：

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>第</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>天：</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>各个评分的卡片数：

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>评分</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished">评分：</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished">容易程度：</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished">重复次数：</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished">错过次数：</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished">自从上次重复的天数：</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished">直到下次重复的天数：</translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>分类</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>卡片</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>统计</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>计划</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>评分</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>分类</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确认(&amp;O)</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>要获得最佳结果，你最好每天做复习。</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>如果你有几天不在，不必担心积压的卡片。要赶回进度，你想复习多少就多少，剩下的会被自动重新安排到以后。</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>“一次学习0分卡片数量”的设置决定你一次试图学习多少新卡片。它&lt;b&gt;不&lt;/b&gt;会告诉你每天需要学习多少新卡片。你是决定者：你可以学习更多或者更少的卡片，取决于你感觉如何。</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>总之，尽量每天做复习，但并不是一定要把“计划”的计数器搞到零，更不必把“未记”的计数器搞到零。</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>1分卡片与0分卡片的不同在于它们更少出现，并且不受“一次学习0分卡片数量”设置的影响。</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>你可以使用键盘快捷键来做你的复习。回车或空格键代表默认动作（“显示答案”或者“打4分”）。数字键可以用于打分。</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>你可以在“激活分类”菜单项里选择你想要学习的分类。</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>建议你把所有卡片都放在一个数据库里，并用分类来组织它们。比起装载、卸载多个数据库，使用“激活分类”要方便多了。</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>你可以导入多种格式的卡片：Tab 分隔的文本文件，Supermemo 文件，...。</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>如果你在 Word 或 Excel 里有卡片，请把它们导出为 UTF-8 编码的 Tab 分隔的文本文件，使之能导入到 Mnemosyne 中。</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>如果你想把你的卡片打印出来，请把它们导出为一个文本文件，这样你就可以在你喜欢的文字处理程序里打印了。</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>你可以跟别人分享你的卡片，只需把它们导出为 XML，并在导出时选择“重置学习数据”选项。</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>如果你在学习一门有非拉丁字符的语言（比如中文），默认的字体大小往往太小了。如果你想要增加这些字符的大小而保持英文文本的大小，请使用“增加非拉丁字符大小X磅(pt)”的选项。</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>你可以给你的卡片添加图片和声音。在编辑卡片时，右击问题或答案框，就会出现一个弹出式菜单来让你完成添加。</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>建议你把你的声音和图片文件放在你的 .mnemosyne 目录里。那样的话，要在不同电脑之间传输你的数据就更容易了。</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>在添加三面卡片时，会有两张常规卡片被创建。一张以文字形式作为问题，发音和翻译作为答案，另一张则以翻译作为问题，文字形式和发音作为答案。</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>你可以在你的卡片里使用基本的 HTML 标签来控制外观。</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemosyne 可以使用 LaTeX 来表达数学公式，如 &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;。（为此，你需要装有 LaTeX 和 dvipng。）</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>备份你的数据的最佳方法是复制你的 .mnemosyne 目录（如果你遵循推荐步骤而把你的所有文件都放在那儿）并把复本移动到另一个驱动器。Mnemosyne 会自动在 .mnemosyne/backups 里保存基于 XML 的备份， 但要是那个驱动器完蛋的话，那个是帮不了你的... </translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>你可以从U盘上运行 Mnemosyne。把 C:\Program Files\Mnemosyne 复制到你的U盘上，然后把 .mnemosyne 目录从你的主目录复制到U盘的 Mnemosyne 目录里。</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>如果你在多台电脑上使用 Mnemosyne，有个好用的工具叫 Unison 能帮你同步你的数据。更多信息请见 Mnemosyne 网站。</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>你可以在“编辑卡片叠”对话框里，通过点击相应的列名，将卡片按答案或分类排序。</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>如果你想对 LaTeX 的行为有更细致的控制， 请见 Mnemosyne 的网站上对 &lt;$$&gt;...&lt;/$$&gt; 和 &lt;latex&gt;...&lt;/latex&gt; 标签的解释。</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>高级用户可以通过编辑他们的 .mnemosyne 目录里的 config.py 文件来对 Mnemosyne 做更多定制。他们也可以安装插件来进一步定制 Mnemosyne。</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>今日提示</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;你知道吗？&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>启动时显示提示(&amp;S)</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>前一条(&amp;P)</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>下一条(&amp;N)</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
